@@ -1,6 +1,7 @@
 use f32 as dp; // dimension
 use crate::cprelude;
 
+use std::ops;
 pub struct Point {
     pub x: dp,
     pub y: dp
@@ -10,10 +11,10 @@ fn square_dp(n: dp) -> dp {
 }
 impl Point {
     pub fn distance_to(&self, other: &Self) -> dp {
-        let delta_x = other.x - self.x;
-        let delta_y = other.y - self.y;
+        let delta_x = other.x-self.x;
+        let delta_y = other.y-self.y;
 
-        (square_dp(delta_x) + square_dp(delta_y))
+        (square_dp(delta_x)+square_dp(delta_y))
             .sqrt()
     }
 }
@@ -21,4 +22,17 @@ impl cprelude::CloseEnough for Point {
     fn is_close_enough_to(&self, other: &Self, tolerance: dp) -> bool {
         self.distance_to(other) <= tolerance
     }
+}
+// Operator Overloaders
+impl ops::Add for Point {
+    type Output = Point;
+    fn add(self, rhs: Self) -> Self {
+        Point {x: self.x+rhs.x, y: self.y+rhs.y}
+    }
+}
+impl ops::Sub for Point {
+    type Output = Point;
+    fn sub(self, rhs: Self) -> Self {
+        self+Point {x: -rhs.x, y: -rhs.y}
+    }
 }
\ No newline at end of file
